@@ -71,6 +71,7 @@ import logging
 # DEFAULUT_USE_COLOR_HANDLER = True  # 是否默认使用有彩的日志。
 # DISPLAY_BACKGROUD_COLOR_IN_CONSOLE = True     # 在控制台是否显示彩色块状的日志。为False则不使用大块的背景颜色。
 # AUTO_PATCH_PRINT = True  # 是否自动打print的猴子补丁，如果打了后指不定，print自动变色和可点击跳转。
+# WARNING_PYCHARM_COLOR_SETINGS = True
 # 
 # DEFAULT_ADD_MULTIPROCESSING_SAFE_ROATING_FILE_HANDLER = False  # 是否默认同时将日志记录到记log文件记事本中。
 # LOG_FILE_SIZE = 100  # 单位是M,每个文件的切片大小，超过多少后就自动切割
@@ -100,7 +101,7 @@ import logging
 #     7: logging.Formatter('%(levelname)s - %(filename)s - %(lineno)d - %(message)s'),  # 一个只显示简短文件名和所处行数的日志模板
 # }
 # 
-# FORMATTER_KIND = 5  # 选择第几个模板
+# FORMATTER_KIND = 5  # 如果get选择第几个模板
 
 '''
 
@@ -110,17 +111,19 @@ def use_config_form_distributed_frame_config_module():
     自动读取配置。会优先读取启动脚本的目录的distributed_frame_config.py文件。没有则读取项目根目录下的distributed_frame_config.py
     :return:
     """
+    line = sys._getframe().f_back.f_lineno
+    file_name = sys._getframe(1).f_code.co_filename
     try:
         m = importlib.import_module('nb_log_config')
         msg = f'nb_log包 读取到\n "{m.__file__}:1" 文件里面的变量作为优先配置了\n'
         # nb_print(msg)
-        line = sys._getframe().f_back.f_lineno
-        file_name = sys._getframe(1).f_code.co_filename
         sys.stdout.write(f'{time.strftime("%H:%M:%S")}  "{file_name}:{line}"   {msg} \n \033[0m')
         for var_namex, var_valuex in m.__dict__.items():
             if var_namex.isupper():
                 setattr(nb_log_config_default, var_namex, var_valuex)
     except ModuleNotFoundError:
+        msg = '在你的项目根目录下生成了 nb_log_config.py 的nb_log包的日志配置文件，快去看看并修改一些自定义配置吧'
+        sys.stdout.write(f'{time.strftime("%H:%M:%S")}  "{file_name}:{line}"   {msg} \n \033[0m')
         auto_creat_config_file_to_project_root_path()
 
 
